@@ -1,21 +1,22 @@
 # -*- coding: utf-8 -*-
-from qlazy.error import *
-from qlazy.config import *
-from qlazy.util import *
+""" multi-controlled cnot for density operator """
 
-# multi-controlled X gate
-
-def __gray_code(de, n):
+def __gray_code(n):
+    """ gray code generator """
 
     for k in range(2**n):
         yield k^(k>>1)
 
-def densop_mcx(de,qid=[]):
+def densop_mcx(de, qid=None):
+    """ multi-controlled cnot """
+
+    if qid is None:
+        raise ValueError("qid must be set.")
 
     # controled and target register
     qid_ctr = qid[:-1]
     qid_tar = qid[-1]
-        
+
     # hadamard
     de.h(qid_tar)
 
@@ -23,7 +24,7 @@ def densop_mcx(de,qid=[]):
     bitnum = len(qid_ctr)
     psi = 1.0/(2**(bitnum-1)) # unit=pi(radian)
     gray_pre = 0
-    for gray in __gray_code(de, bitnum):
+    for gray in __gray_code(bitnum):
         if gray == 0:
             continue
         msb = len(str(bin(gray)))-3
@@ -35,6 +36,6 @@ def densop_mcx(de,qid=[]):
         de.cp(qid_ctr[msb], qid_tar, phase=psi)
         psi = -psi
         gray_pre = gray
-    
+
     # hadamard
     de.h(qid_tar)
